@@ -26,7 +26,6 @@ import traceback
 from datetime import datetime, timezone
 from typing import Any, Coroutine, Dict, List
 
-import cloudpickle as pickle
 import dask
 from dask.distributed import Client, Variable
 
@@ -45,7 +44,6 @@ from covalent._shared_files.defaults import (
     sublattice_prefix,
     subscript_prefix,
 )
-from covalent._shared_files.util_classes import TaskExecutionMetadata
 from covalent._workflow.lattice import Lattice
 from covalent.executor import _executor_manager
 from covalent_ui import result_webhook
@@ -146,7 +144,7 @@ def _run_task(
     node_id: int,
 ) -> None:
     """
-    Run a task with given inputs on the selected backend.
+    Run a task with given inputs on the selected executor.
     Also updates the status of current node execution while
     checking if a redispatch has occurred. Exclude those nodes
     from execution which were completed.
@@ -163,7 +161,9 @@ def _run_task(
     """
 
     serialized_callable = result_object.lattice.transport_graph.get_node_value(node_id, "function")
-    task_md = result_object.lattice.transport_graph.get_node_value(node_id, "exec_plan")
+    selected_executor = result_object.lattice.transport_graph.get_node_value(node_id, "metadata")[
+        "executor"
+    ]
     node_name = (
         result_object.lattice.transport_graph.get_node_value(node_id, "name") + f"({node_id})"
     )
@@ -191,7 +191,7 @@ def _run_task(
         return
 
     # the executor is determined during scheduling and provided in the execution metadata
-    executor = _executor_manager.get_executor(task_md.selected_executor)
+    executor = _executor_manager.get_executor(selected_executor)
 
     # run the task on the executor and register any failures
     try:
@@ -224,8 +224,8 @@ def _run_task(
             output, stdout, stderr = executor.execute(
                 serialized_callable,
                 inputs,
-                task_md.execution_args,
                 result_object.dispatch_id,
+                result_object.results_dir,
                 node_id,
             )
 
@@ -354,8 +354,9 @@ def _run_planned_workflow(result_object: Result) -> Result:
 
 def _plan_workflow(result_object: Result) -> None:
     """
-    Plan the workflow for execution, assigning the executor to each node
-    and assigning some common execution arguments to each node.
+    Function to plan a workflow according to a schedule.
+    Planning means to decide which executors (along with their arguments) will
+    be used by each node.
 
     Args:
         result_object: Result object being used for current dispatch
@@ -364,35 +365,13 @@ def _plan_workflow(result_object: Result) -> None:
         None
     """
 
-    serialized_tg = result_object.lattice.transport_graph.serialize(metadata_only=True)
+    if result_object.lattice.get_metadata("schedule"):
+        # Custom scheduling logic of the format:
+        # scheduled_executors = get_schedule(result_object)
 
-    schedule = result_object.lattice.transport_graph.lattice_metadata.get("schedule", False)
-
-    if schedule:
-        # Custom scheduling logic
+        # for node_id, executor in scheduled_executors.items():
+        #    result_object.lattice.transport_graph.set_node_value(node_id, "executor", executor)
         pass
-    else:
-        # Default scheduling logic
-        workflow_schedule = {"nodes": [], "schedule_quality": 1}
-        deserialized_tg = pickle.loads(serialized_tg)
-
-        # Certain metadata fields are transformed and passed to the executor
-        for node in deserialized_tg["nodes"]:
-            workflow_schedule["nodes"].append(
-                {
-                    "id": node["id"],
-                    "backend": node["metadata"]["backend"][0]
-                    if isinstance(node["metadata"]["backend"], list)
-                    else node["metadata"]["backend"],
-                    # Mutate executor-specific arguments here
-                    "backend_args": {"results_dir": result_object.results_dir},
-                }
-            )
-
-    # Attach the execution plan to the transport graph
-    for node in workflow_schedule["nodes"]:
-        exec_plan = TaskExecutionMetadata(node["backend"], node["backend_args"])
-        result_object._lattice.transport_graph.set_node_value(node["id"], "exec_plan", exec_plan)
 
 
 def run_workflow(dispatch_id: str, results_dir: str) -> None:
